@@ -23,4 +23,4 @@
 # along with qmath. If not, see <http://www.gnu.org/licenses/>.
 #
 # .-
-from qmath import *
+from qmathcore import *
